@@ -5,7 +5,7 @@ set_project("tbox")
 set_xmakever("2.8.2")
 
 -- set project version
-set_version("1.7.6", {build = "%Y%m%d", soname = true})
+set_version("1.7.7", {build = "%Y%m%d", soname = true})
 
 -- set warning all as error
 set_warnings("all", "error")
@@ -66,7 +66,13 @@ if has_config("small", "micro") then
         -- TODO we should fix it in context code later
         -- https://github.com/tboox/tbox/issues/175
         not has_config("coroutine") then
-        set_optimize("smallest")
+        if is_plat("windows") then
+            -- we cannot use smallest(/O1), it maybe generates incorrect code for msvc2022
+            -- @see https://github.com/tboox/tbox/issues/272
+            set_optimize("fastest")
+        else
+            set_optimize("smallest")
+        end
     end
     add_cxflags("-fno-stack-protector")
 end
